%define oname   The-Powder-Toy

Name:           powdertoy
Version:        91.5.330
Release:        %mkrel 1
Summary:        Falling-sand physics sandbox game
Group:          Games/Simulation
License:        GPLv3+
Url:            http://powdertoy.co.uk
Source0:        https://github.com/simtr/The-Powder-Toy/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:         powdertoy-91.3.328-mga-lua5.1-pkgconfig.patch

BuildRequires:  bzip2-devel
BuildRequires:  imagemagick
BuildRequires:  lua5.1-devel
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  scons

%description
The Powder Toy is a free physics sandbox game, which simulates
air pressure and velocity, heat, gravity and a countless number
of interactions between different substances! The game provides
you with various building materials, liquids, gases and electronic
components which can be used to construct complex machines, guns,
bombs, realistic terrains and almost anything else.

%prep
%setup -q -n %{oname}-%{version}
%autopatch -p1

%build
%setup_compile_flags
export CPPDEFINES="NO_INSTALL_CHECK"
%scons --debugging \
%ifnarch x86_64
       --no-sse
%endif

%install
# Game binary
%ifarch x86_64
  %define archsuffix "64"
%else
%ifarch %ix86
  %define archsuffix "-legacy"
%else
  %define archsuffix ""
%endif
%endif
install -D -m755 build/powder%{archsuffix} %{buildroot}%{_libexecdir}/%{name}/powder

# Wrapper script
cat << EOF > %{name}.sh
#!/bin/sh
CONFIGDIR=\$HOME"/.config/%{name}"

if [ ! -e \$CONFIGDIR ];
then
    echo -e "Creating the config directory for The Powder Toy in\n\$CONFIGDIR"
    mkdir -p \$CONFIGDIR
fi

pushd \$CONFIGDIR
exec %{_libexecdir}/%{name}/powder \$@
popd
EOF

install -D -m755 %{name}.sh %{buildroot}%{_gamesbindir}/%{name}

# Icons
pushd resources
  convert powder.ico powder.png
  install -D -m644 powder-0.png %{buildroot}%{_iconsdir}/hicolor/256x256/apps/%{name}.png
  install -D -m644 powder-1.png %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png
  install -D -m644 powder-2.png %{buildroot}%{_iconsdir}/hicolor/32x32/apps/%{name}.png
  install -D -m644 powder-3.png %{buildroot}%{_iconsdir}/hicolor/24x24/apps/%{name}.png
  install -D -m644 powder-4.png %{buildroot}%{_iconsdir}/hicolor/16x16/apps/%{name}.png
popd

# Desktop entry
install -d %{buildroot}%{_datadir}/applications
cat << EOF > %{buildroot}%{_datadir}/applications/%{name}.desktop
[Desktop Entry]
Name=The Powder Toy
GenericName=Physics sandbox
Comment=%{summary}
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Game;Simulation;
EOF

%files
%doc LICENSE README
%{_gamesbindir}/%{name}
%{_libexecdir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png


%changelog
* Sat Aug 13 2016 akien <akien> 91.5.330-1.mga6
+ Revision: 1046149
- Version 91.5.330

* Sun Apr 24 2016 akien <akien> 91.3.328-1.mga6
+ Revision: 1005860
- Version 91.3.328

* Thu Dec 24 2015 pterjan <pterjan> 90.2.322-4.mga6
+ Revision: 914036
- On i586 the binary gets renamed -legacy when sse is disabled...
- Only enable SSE/SSE2 for x86_64, arm really doesn't like it

* Thu Dec 24 2015 daviddavid <daviddavid> 90.2.322-2.mga6
+ Revision: 914008
- compile with debug symbols adding --debugging scons option

* Mon Jan 26 2015 akien <akien> 90.2.322-1.mga5
+ Revision: 812353
- imported package powdertoy

